@@ -48,11 +48,19 @@ END
 
    BOOKMARK => 'Bookmark this',
 
-   IMAGE_LINK => 'Link to Image',
+   EXPORT => 'Export as...',
 
-   SVG_LINK   => 'High-res Image',
+   IMAGE_LINK => '...low-res image',
 
-   PDF_LINK   => 'Download PDF',
+   SVG_LINK   => '...high-res image',
+
+   PDF_LINK   => '...PDF',
+
+   DUMP_GFF   => '...GFF annotation table',
+
+   DUMP_SEQ   => '...FASTA sequence file',
+
+   FILTER     => 'Filter',
 
    SVG_DESCRIPTION => <<END,
 <p>
@@ -127,7 +135,7 @@ END
 
    SCROLL   => 'Scroll/Zoom',
 
-   RESET    => 'Reset',
+   RESET    => 'Reset to defaults',
 
    FLIP     => 'Flip',
 
@@ -141,6 +149,10 @@ END
 
    TRACKS   => 'Tracks',
 
+   TRACK_SELECT   => 'Search for Specific Tracks',
+
+   TRACK_NAME     => 'Track name',
+
    EXTERNAL_TRACKS => '<i>External tracks italicized</i>',
 
    OVERVIEW_TRACKS => '<sup>*</sup>Overview track',
@@ -157,7 +169,7 @@ END
 
    CANCEL   => 'Cancel',
 
-   ABOUT    => 'About...',
+   ABOUT    => 'About GBrowse...',
 
    REDISPLAY   => 'Redisplay',
 
@@ -165,6 +177,8 @@ END
 
    CONFIGURE_TRACKS   => 'Configure tracks...',
 
+   SELECT_SUBTRACKS   => 'Click to select subtracks...',
+
    EDIT       => 'Edit File...',
 
    DELETE     => 'Delete File',
@@ -193,6 +207,8 @@ END
 
    CLEAR_HIGHLIGHTING => 'Clear highlighting',
 
+   CLEAR       => 'Clear',
+
    UPDATE      => 'Update',
 
    UPDATE_TRACKS => 'Update Tracks',
@@ -205,9 +221,17 @@ END
 
    UPLOAD_TRACKS=>'Add custom tracks',
 
+   USERDATA_TABLE=>'Upload and share tracks',
+
+   USERIMPORT_TABLE=>'Import tracks',
+
    UPLOAD_TITLE=> 'Upload your own data',
 
-   UPLOAD_FILE => 'Upload a file',
+   UPLOAD_FILE => 'Upload a track',
+
+   IMPORT_TRACK => 'Import a track',
+
+   REMOVE       => 'Remove',
 
    KEY_POSITION => 'Key position',
 
@@ -366,8 +390,6 @@ END
 
    NO_EXTERNAL        => 'No external features loaded.',
 
-   NO_CITATION        => 'No additional information available.',
-
    #--------------
    # PLUGIN PAGES
    #--------------
@@ -440,44 +462,50 @@ END
 
  OPTIONS_UPDATED   => 'A new site configuration is in effect; all page settings have been reset to their defaults',
 
- SEND_TO_GALAXY    => 'Send to Galaxy',
+ SEND_TO_GALAXY    => 'Export to Galaxy',
 
  NO_DAS            => 'Installation error: Bio::Das module must be installed for DAS URLs to work. Please inform this site\'s webmaster.',
 
  SHOW_OR_HIDE_TRACK => '<b>Show or hide this track</b>',
 
- CONFIGURE_THIS_TRACK   => '<b class="error">Configure this track.</b>',
+ KILL_THIS_TRACK    => '<b>Turn off this track.</b>',
+
+ CONFIGURE_THIS_TRACK   => '<b>Click to configure this track.</b>',
 
  SUBTRACKS_SHOWN    => 'This track contains selectable subtracks:',
 
  SHOW_SUBTRACKS     => '<b>Select subtracks</b>',
 
+ SHOWING_SUBTRACKS  => '(<i>Showing %d of %d subtracks</i>)',
+
  SHARE_THIS_TRACK   => '<b>Share this track</b>',
 
- SHARE_ALL          => 'Share these tracks',
+ SHARE_ALL          => 'Share/Export these tracks',
 
- SHARE              => 'Share %s',
+ SHARE              => 'Share/Export %s',
+
+ SHARE_INSTRUCTIONS_BOOKMARK => <<END,
+To <b>share</b> this track with another user, copy the URL below and
+send it to him or her.
+END
 
  SHARE_INSTRUCTIONS_ONE_TRACK => <<END,
-To share this track with another GBrowse genome browser,
-first copy the URL below, then go to the other GBrowse and
-paste the URL into the "Enter remote track URL" field at
-the bottom of the page. If this track is from an uploaded file,
-then be aware that sharing this URL with another user potentially
-allows <b>all</b> your uploaded data to be viewable by that user.
+To <b>export</b> this track to a GBrowse genome browser running on
+another server,
+first copy the URL below, then go to the other GBrowse, 
+select the "Upload and Share Tracks" tab and
+paste the URL into the "Import tracks" section at the bottom.
 END
 
  SHARE_INSTRUCTIONS_ALL_TRACKS => <<END,
-To share all currently selected tracks with another GBrowse genome
-browser, first copy the URL below, then go to the other GBrowse and
-paste the URL into the "Enter remote track URL" field at
-the bottom of the page. If any of the selected tracks are from an uploaded file,
-then be aware that sharing this URL with another user potentially
-allows <b>all</b> your uploaded data to be viewable by that user.
+To <b>export</b> all currently selected tracks to another GBrowse genome
+browser, first copy the URL below, then go to the other GBrowse,
+select the "Upload and Share Tracks" tab and
+paste the URL into the "Import tracks" section at the bottom.
 END
 
  SHARE_DAS_INSTRUCTIONS_ONE_TRACK => <<END,
-To share this track with another genome browser using 
+To <b>export</b> this track with another genome browser using 
 the <a href="http://www.biodas.org" target="_new">
 Distributed Annotation System (DAS)</a> first copy the URL below, 
 then go to the other browser and enter it as a new DAS source.
@@ -486,11 +514,15 @@ be shared using DAS.</i>
 END
 
  SHARE_DAS_INSTRUCTIONS_ALL_TRACKS => <<END,
-To share all currently selected tracks with another genome browser
+To <b>export</b> all currently selected tracks with another genome browser
 using the <a href="http://www.biodas.org" target="_new"> Distributed
 Annotation System (DAS)</a> first copy the URL below, then go to the
 other browser and enter it as a new DAS source. <i>Quantitative tracks
 ("wiggle" files) and uploaded files can not be shared using DAS.</i>
 END
 
+    MAIN_PAGE          => 'Browser',
+    CUSTOM_TRACKS_PAGE => 'Upload and Share Tracks',
+    SETTINGS_PAGE      => 'Preferences',
+
 };
